type RustlsInner = CompoundRuntime<AsyncStd, AsyncStd, RealCoarseTimeProvider, AsyncStd, AsyncStd, RustlsProvider, AsyncStd>;Expand description
Implementation type for AsyncStdRustlsRuntime.
Aliased Type
struct RustlsInner {
inner: Arc<Inner<AsyncStd, AsyncStd, RealCoarseTimeProvider, AsyncStd, AsyncStd, RustlsProvider, AsyncStd>>,
}Fields
inner: Arc<Inner<AsyncStd, AsyncStd, RealCoarseTimeProvider, AsyncStd, AsyncStd, RustlsProvider, AsyncStd>>The actual collection of Runtime objects.
We wrap this in an Arc rather than requiring that each item implement Clone, though we could change our minds later on.