#[non_exhaustive]pub struct RustlsProvider {
config: Arc<ClientConfig>,
}Expand description
A TlsProvider that uses rustls.
It supports wrapping any reasonable stream type that implements AsyncRead + AsyncWrite.
Cryptographic providers
The application is responsible for calling CryptoProvider::install_default()
before constructing TlsProvider. If they do not, rustls will fail,
and arti will not run.
We currently recommend the aws-lc-rs provider because, of the two builtin providers that ship with rustls, it appears to have better performance, and it supports hybrid post-quantum handshakes. It used to have a problematic license, but this has been fixed since March 2026.
See the rustls documentation for a list of other rustls cryptography providers.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.config: Arc<ClientConfig>Inner ClientConfig logic used to create connectors.
Implementations
Sourceimpl RustlsProvider
impl RustlsProvider
Sourcepub(crate) fn new() -> Self
pub(crate) fn new() -> Self
Construct a new RustlsProvider.