macro_rules! stream_impl {
{
$kind:ident,
$addr:ty,
$cvt_addr:ident
} => { ... };
}Expand description
Provide a set of network stream wrappers for a single stream type.
macro_rules! stream_impl {
{
$kind:ident,
$addr:ty,
$cvt_addr:ident
} => { ... };
}Provide a set of network stream wrappers for a single stream type.