pub struct TokioRuntimeHandle {
owned: Option<TokioTp>,
handle: Handle,
}Expand description
Wrapper around a Handle to a tokio runtime.
Ideally, this type would go away, and we would just use
tokio::runtime::Handle directly. Unfortunately, we can’t implement
futures::Spawn on it ourselves because of Rust’s orphan rules, so we need
to define a new type here.
Limitations
Note that Arti requires that the runtime should have working implementations for Tokio’s time, net, and io facilities, but we have no good way to check that when creating this object.
Fields
owned: Option<TokioTp>If present, the tokio executor that we’ve created (and which we own).
We never access this directly; only through handle. We keep it here
so that our Runtime types can be agnostic about whether they own the
executor.
handle: HandleThe underlying Handle.
Implementations
Sourceimpl TokioRuntimeHandle
impl TokioRuntimeHandle
Sourcepub(crate) fn new(handle: Handle) -> Self
pub(crate) fn new(handle: Handle) -> Self
Wrap a tokio runtime handle into a format that Arti can use.
Limitations
Note that Arti requires that the runtime should have working implementations for Tokio’s time, net, and io facilities, but we have no good way to check that when creating this object.