implement_opaque_runtime

Macro implement_opaque_runtime 

macro_rules! implement_opaque_runtime {
    {
    $t:ty { $member:ident : $mty:ty }
} => { ... };
}
Implement delegating implementations of the runtime traits for a type $t whose member $r implements Runtime. Used to hide the details of the implementation of $t.