pub struct TaskSchedule<R: SleepProvider> { /* private fields */ }Expand description
A remotely-controllable trigger for recurring tasks.
This implements [Stream], and is intended to be used in a while loop; you should
wrap your recurring task in a while schedule.next().await.is_some() or similar.
Implementations
Sourceimpl<R: SleepProvider> TaskSchedule<R>
impl<R: SleepProvider> TaskSchedule<R>
Sourcepub fn new(rt: R) -> (Self, TaskHandle)
pub fn new(rt: R) -> (Self, TaskHandle)
Create a new schedule, and corresponding handle.
Sourcepub async fn sleep(&mut self, dur: Duration) -> Result<(), SleepError>
pub async fn sleep(&mut self, dur: Duration) -> Result<(), SleepError>
Wait until Dur has elapsed.
This call is equivalent to SleepProvider::sleep, except that the
resulting future will respect calls to the functions on this schedule’s
associated TaskHandle.
Alternatively, you can view this function as equivalent to
self.fire_in(dur); self.next().await;, only with the intent made more
explicit.
If the associated TaskHandle for this schedule is suspended, then
this method will not return until the schedule is unsuspended and the
timer elapses. If the associated TaskHandle is cancelled, then this
method will not return at all, until the schedule is re-activated by
TaskHandle::fire or TaskHandle::fire_at.
Finally, if every associated TaskHandle has been dropped, then this
method will return an error.
Sourcepub async fn sleep_until_wallclock(
&mut self,
when: SystemTime,
) -> Result<(), SleepError>
pub async fn sleep_until_wallclock( &mut self, when: SystemTime, ) -> Result<(), SleepError>
As
sleep_until_wallclock,
but respect messages from this schedule’s associated TaskHandle.