NativeTlsInner

Type Alias NativeTlsInner 

type NativeTlsInner = CompoundRuntime<SmolRuntime, SmolRuntime, RealCoarseTimeProvider, SmolRuntime, SmolRuntime, NativeTlsProvider, SmolRuntime>;
Implementation type for SmolRuntime using NativeTls.

Aliased Type

struct NativeTlsInner {
    inner: Arc<Inner<SmolRuntime, SmolRuntime, RealCoarseTimeProvider, SmolRuntime, SmolRuntime, NativeTlsProvider, SmolRuntime>>,
}

Fields

inner: Arc<Inner<SmolRuntime, SmolRuntime, RealCoarseTimeProvider, SmolRuntime, SmolRuntime, NativeTlsProvider, SmolRuntime>>

The actual collection of Runtime objects.

We wrap this in an Arc rather than requiring that each item implement Clone, though we could change our minds later on.