#[non_exhaustive]pub struct CommonConnectOptions { /* private fields */ }Expand description
Options to use when connecting a socket.
This may include both options that affect the connection attempt, and options that will apply to the resulting connection stream.
It can include options set with setsockopt,
as well as options that influence higher layers (eg, the runtime).
For established streams,
you can use StreamOps to perform additional operations
or to configure additional options.
Implementations
Sourceimpl CommonConnectOptions
impl CommonConnectOptions
Sourcepub fn send_buffer_size(&self) -> &Option<usize>
pub fn send_buffer_size(&self) -> &Option<usize>
Method borrowing CommonConnectOptions::send_buffer_size field.
Value set for SO_SNDBUF on the socket.
Sourcepub fn recv_buffer_size(&self) -> &Option<usize>
pub fn recv_buffer_size(&self) -> &Option<usize>
Method borrowing CommonConnectOptions::recv_buffer_size field.
Value set for SO_RCVBUF on the socket.
Sourceimpl CommonConnectOptions
impl CommonConnectOptions
Sourcepub fn builder() -> CommonConnectOptionsBuilder
pub fn builder() -> CommonConnectOptionsBuilder
Returns a builder for this CommonConnectOptions.