CommonListenOptions

Struct CommonListenOptions 

#[non_exhaustive]
pub struct CommonListenOptions { pub(crate) send_buffer_size: Option<usize>, pub(crate) recv_buffer_size: Option<usize>, }
Options to use when initializing a listening socket.

This may include both options that affect the listening, and options that will apply to any individual accepted connection streams.

It can include options set with setsockopt, as well as options that influence higher layers (eg, the runtime).

For established streams that are accepted from a listener, you can use StreamOps to perform additional operations or to configure additional options.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
send_buffer_size: Option<usize>

Value set for SO_SNDBUF on the listening socket.

recv_buffer_size: Option<usize>

Value set for SO_RCVBUF on the listening socket.

Implementations

Source

impl CommonListenOptions

pub fn send_buffer_size(&self) -> &Option<usize>

Method borrowing CommonListenOptions::send_buffer_size field. Value set for SO_SNDBUF on the listening socket.

pub fn recv_buffer_size(&self) -> &Option<usize>

Method borrowing CommonListenOptions::recv_buffer_size field. Value set for SO_RCVBUF on the listening socket.

Source

impl CommonListenOptions

pub fn builder() -> CommonListenOptionsBuilder

Returns a builder for this CommonListenOptions.