Function tor_rtcompat::task::yield_now
source · pub fn yield_now() -> YieldFuture ⓘExpand description
Yield execution back to the runtime temporarily, so that other tasks can run.
pub fn yield_now() -> YieldFuture ⓘYield execution back to the runtime temporarily, so that other tasks can run.