#[non_exhaustive]pub struct RustlsProvider { /* private fields */ }Available on (crate features
native-tls or rustls) and (crate features async-std or tokio or smol) and crate feature rustls only.Expand description
A TlsProvider that uses rustls.
It supports wrapping any reasonable stream type that implements AsyncRead + AsyncWrite.
Cryptographic providers
The application is responsible for calling CryptoProvider::install_default()
before constructing TlsProvider. If they do not, rustls will fail,
and arti will not run.
We currently recommend the aws-lc-rs provider because, of the two builtin providers that ship with rustls, it appears to have better performance, and it supports hybrid post-quantum handshakes. It used to have a problematic license, but this has been fixed since March 2026.
See the rustls documentation for a list of other rustls cryptography providers.