pub struct TokioNativeTlsRuntime { /* private fields */ }Available on crate feature
native-tls and crate feature tokio and (crate features native-tls or rustls) only.Expand description
Implementations
Sourceimpl TokioNativeTlsRuntime
impl TokioNativeTlsRuntime
Sourcepub fn create() -> IoResult<Self>
pub fn create() -> IoResult<Self>
Create a new TokioNativeTlsRuntime.
The return value will own the underlying Tokio runtime object, which will be dropped when the last copy of this handle is freed.
If you want to use a currently running runtime instead, call
TokioNativeTlsRuntime::current().
Sourcepub fn current() -> IoResult<Self>
pub fn current() -> IoResult<Self>
Return a TokioNativeTlsRuntime wrapping the currently running
Tokio runtime.
Usage note
We should never call this from inside other Arti crates, or from library
crates that want to support multiple runtimes! This function is for
Arti users who want to wrap some existing Tokio runtime as a
Runtime. It is not for library crates that want to work with
multiple runtimes.
Once you have a runtime returned by this function, you should just
create more handles to it via Clone.