HandleInner

Type Alias HandleInner 

type HandleInner = CompoundRuntime<TokioRuntimeHandle, TokioRuntimeHandle, RealCoarseTimeProvider, TokioRuntimeHandle, TokioRuntimeHandle, NativeTlsProvider, TokioRuntimeHandle>;
Implementation type for a TokioRuntimeHandle.

Aliased Type

struct HandleInner {
    inner: Arc<Inner<TokioRuntimeHandle, TokioRuntimeHandle, RealCoarseTimeProvider, TokioRuntimeHandle, TokioRuntimeHandle, NativeTlsProvider, TokioRuntimeHandle>>,
}

Fields

inner: Arc<Inner<TokioRuntimeHandle, TokioRuntimeHandle, RealCoarseTimeProvider, TokioRuntimeHandle, TokioRuntimeHandle, NativeTlsProvider, TokioRuntimeHandle>>

The actual collection of Runtime objects.

We wrap this in an Arc rather than requiring that each item implement Clone, though we could change our minds later on.