RustlsHandleInner

Type Alias RustlsHandleInner 

type RustlsHandleInner = CompoundRuntime<TokioRuntimeHandle, TokioRuntimeHandle, RealCoarseTimeProvider, TokioRuntimeHandle, TokioRuntimeHandle, RustlsProvider, TokioRuntimeHandle>;
Implementation for a TokioRuntimeRustlsHandle

Aliased Type

struct RustlsHandleInner {
    inner: Arc<Inner<TokioRuntimeHandle, TokioRuntimeHandle, RealCoarseTimeProvider, TokioRuntimeHandle, TokioRuntimeHandle, RustlsProvider, TokioRuntimeHandle>>,
}

Fields

inner: Arc<Inner<TokioRuntimeHandle, TokioRuntimeHandle, RealCoarseTimeProvider, TokioRuntimeHandle, TokioRuntimeHandle, RustlsProvider, TokioRuntimeHandle>>

The actual collection of Runtime objects.

We wrap this in an Arc rather than requiring that each item implement Clone, though we could change our minds later on.