type NativeTlsInner = CompoundRuntime<AsyncStd, AsyncStd, RealCoarseTimeProvider, AsyncStd, AsyncStd, NativeTlsProvider, AsyncStd>;Expand description
Implementation type for AsyncStdRuntime.
Aliased Type
struct NativeTlsInner {
inner: Arc<Inner<AsyncStd, AsyncStd, RealCoarseTimeProvider, AsyncStd, AsyncStd, NativeTlsProvider, AsyncStd>>,
}Fields
inner: Arc<Inner<AsyncStd, AsyncStd, RealCoarseTimeProvider, AsyncStd, AsyncStd, NativeTlsProvider, AsyncStd>>The actual collection of Runtime objects.
We wrap this in an Arc rather than requiring that each item implement Clone, though we could change our minds later on.