fn ensure_testing_provider_installed()Expand description
Try to install a default crypto provider if none has been installed, so that Rustls can operate.
We only use this for testing: It is the application’s responsibility to install a CryptoProvider.