type RustlsInner = CompoundRuntime<SmolRuntime, SmolRuntime, RealCoarseTimeProvider, SmolRuntime, SmolRuntime, RustlsProvider, SmolRuntime>;Expand description
Implementation type for SmolRuntime using Rustls.
Aliased Type
struct RustlsInner {
inner: Arc<Inner<SmolRuntime, SmolRuntime, RealCoarseTimeProvider, SmolRuntime, SmolRuntime, RustlsProvider, SmolRuntime>>,
}Fields
inner: Arc<Inner<SmolRuntime, SmolRuntime, RealCoarseTimeProvider, SmolRuntime, SmolRuntime, RustlsProvider, SmolRuntime>>The actual collection of Runtime objects.
We wrap this in an Arc rather than requiring that each item implement Clone, though we could change our minds later on.