pub trait BlockOn: Clone + Send + Sync + 'static { fn block_on<F: Future>(&self, future: F) -> F::Output; }
Trait for a runtime that can block on a future.
Run future until it is ready, and return its output.
future