pub trait StreamOps {
// Provided methods
fn set_tcp_notsent_lowat(&self, _notsent_lowat: u32) -> IoResult<()> { ... }
fn new_handle(&self) -> Box<dyn StreamOps + Send + Unpin> { ... }
}Expand description
Trait providing additional operations on network sockets.
Provided Methods
Sourcefn set_tcp_notsent_lowat(&self, _notsent_lowat: u32) -> IoResult<()>
fn set_tcp_notsent_lowat(&self, _notsent_lowat: u32) -> IoResult<()>
Set the TCP_NOTSENT_LOWAT socket option, if this Stream is a TCP stream.
Implementations should return an UnsupportedStreamOp IO error
if the stream is not a TCP stream,
and on platforms where the operation is not supported.
Implementations on Foreign Types
Sourceimpl StreamOps for UnixStream
Available on Unix only.
impl StreamOps for UnixStream
Available on Unix only.
Sourceimpl StreamOps for UnixStream
Available on Unix only.
impl StreamOps for UnixStream
Available on Unix only.
Implementors
impl StreamOps for Stream
impl StreamOps for TcpSockFd
Available on Linux only.
impl StreamOps for tor_rtcompat::impls::tokio::net::TcpStream
impl StreamOps for tor_rtcompat::impls::tokio::net::UnixStream
Available on Unix only.